@@ -38,7 +38,7 @@
 ;;; Channel movement:
 (defun riece-command-switch-to-channel (channel)
   (interactive
-   (list (completing-read "Channel/user: "
+   (list (completing-read "Channel/User: "
 			  (mapcar #'list riece-current-channels)
 			  nil t)))
   (riece-switch-to-channel channel)
@@ -127,18 +127,6 @@
 	(not riece-channel-list-buffer-mode))
   (riece-command-configure-windows))
 
-(defun riece-get-users-on-server ()
-  (riece-with-server-buffer
-   (let (users)
-     (mapatoms
-      (lambda (atom)
-	(unless (riece-channel-p (symbol-name atom))
-	  (push (symbol-name atom) users)))
-      riece-obarray)
-     (if (member riece-real-nickname users)
-	 users
-       (cons riece-real-nickname users)))))
-
 (defun riece-command-finger (user &optional recurse)
   (interactive
    (let* ((completion-ignore-case t)
@@ -227,7 +215,7 @@
 	  (channel
 	   (if current-prefix-arg
 	       (completing-read
-		"Channel/user: "
+		"Channel/User: "
 		(mapcar #'list riece-current-channels))
 	     riece-current-channel))
 	  (riece-overriding-server-name (riece-identity-server channel))
@@ -266,7 +254,8 @@
      (list users current-prefix-arg)))
   (let (group)
     (while users
-      (push (pop users) group)
+      (setq group (cons (car users) group)
+	    users (cdr users))
       (if (or (= (length group) 3)
 	      (null users))
 	  (riece-send-string
@@ -297,7 +286,8 @@
      (list users current-prefix-arg)))
   (let (group)
     (while users
-      (push (pop users) group)
+      (setq group (cons (car users) group)
+	    users (cdr users))
       (if (or (= (length group) 3)
 	      (null users))
 	  (riece-send-string
@@ -360,7 +350,7 @@
   (interactive
    (let ((completion-ignore-case t)
 	 (target
-	  (completing-read "Channel/user: "
+	  (completing-read "Channel/User: "
 			   (mapcar #'list riece-current-channels)))
 	 key)
      (if (and current-prefix-arg
@@ -396,7 +386,7 @@
   (interactive
    (let ((completion-ignore-case t)
 	 (target
-	  (completing-read "Channel/user: "
+	  (completing-read "Channel/User: "
 			   (mapcar #'list riece-current-channels)
 			   nil t (cons riece-current-channel 0)))
 	 message)
@@ -535,7 +525,9 @@ If prefix argument ARG is non-nil, toggle frozen status."
 		  server-name)))
     (with-current-buffer (process-buffer process)
       (setq riece-server-name server-name))
-    (push (cons server-name process) riece-server-process-alist)))
+    (setq riece-server-process-alist
+	  (cons (cons server-name process)
+		riece-server-process-alist))))
 
 (defun riece-command-close-server (server-name &optional message)
   (interactive
