@@ -162,35 +162,25 @@
 
 (defcustom riece-highlight-font-lock-keywords
   (append
-   (list
-    `(,(concat
-	"^\\(" riece-time-prefix-regexp "\\)?"
-	"\\(\\([][<>(-][][<>(-]?[^<>)]*[][<>)-][][<>)-]?\\)\\|"
-	"\\(=[^ ]*=\\|\\*\\*[^ \*]*\\*\\*\\)\\) ")
-      (3 riece-prefix-face append t)))
+   (list (list (concat "^" riece-time-prefix-regexp
+		       "\\(<[^>]+>\\|>[^<]+<\\|([^)]+)\\|{[^}]+}\\|=[^=]+=\\)")
+	       '(1 riece-prefix-face append t)))
    ;; set property to the whole line
    (mapcar
     (lambda (line)
       (cons
        (concat
-	"^\\(" riece-time-prefix-regexp "\\)?\\("
+	"^" riece-time-prefix-regexp "\\("
 	(regexp-quote
 	 (symbol-value (intern (format "riece-%s-prefix" line))))
 	".*\\)$")
-       (list 2 (intern (format "riece-%s-face" line)) t t)))
+       (list 1 (intern (format "riece-%s-face" line)) t t)))
     '(change notice wallops error info))
    (list (list "(from [^)]+)$" 0 riece-server-face t)))
   "Normal and deformed faces for IRC normal line."
   :type '(repeat (list string))
   :group 'riece-highlight)
 
-(put 'riece-channel-mode 'font-lock-defaults
-     '(riece-highlight-font-lock-keywords t))
-(put 'riece-others-mode 'font-lock-defaults
-     '(riece-highlight-font-lock-keywords t))
-(put 'riece-dialogue-mode 'font-lock-defaults
-     '(riece-highlight-font-lock-keywords t))
-
 (defun riece-highlight-schedule-turn-on-font-lock ()
   (add-hook 'riece-channel-mode-hook
 	    'riece-highlight-turn-on-font-lock)
@@ -199,9 +189,6 @@
   (add-hook 'riece-dialogue-mode-hook
 	    'riece-highlight-turn-on-font-lock))
 
-(add-hook 'riece-after-load-startup-hook
-	  'riece-highlight-schedule-turn-on-font-lock)
-
 (defvar font-lock-support-mode)
 (defun riece-highlight-turn-on-font-lock ()
   (make-local-variable 'font-lock-defaults)
@@ -224,6 +211,16 @@
     (if (looking-at riece-prefix-regexp)
 	(put-text-property (match-beginning 1) (match-end 1) 'invisible t))))
 
+(defun riece-highlight-insinuate ()
+  (put 'riece-channel-mode 'font-lock-defaults
+       '(riece-highlight-font-lock-keywords t))
+  (put 'riece-others-mode 'font-lock-defaults
+       '(riece-highlight-font-lock-keywords t))
+  (put 'riece-dialogue-mode 'font-lock-defaults
+       '(riece-highlight-font-lock-keywords t))
+  (add-hook 'riece-after-load-startup-hook
+	    'riece-highlight-schedule-turn-on-font-lock))
+
 (provide 'riece-highlight)
 
 ;;; riece-highlight.el ends here
