@@ -35,8 +35,8 @@
 
 (defun riece-get-buffer-create (name)
   (let ((buffer (get-buffer-create name)))
-    (or (memq buffer riece-buffer-list)
-	(push buffer riece-buffer-list))
+    (unless (memq buffer riece-buffer-list)
+      (setq riece-buffer-list (cons buffer riece-buffer-list)))
     buffer))
 
 (defun riece-insert (buffers string)
@@ -167,6 +167,18 @@
       (substring user-at-host 1)
     user-at-host))
 
+(defun riece-get-users-on-server ()
+  (riece-with-server-buffer
+   (let (users)
+     (mapatoms
+      (lambda (atom)
+	(unless (riece-channel-p (symbol-name atom))
+	  (setq users (cons (symbol-name atom) users))))
+      riece-obarray)
+     (if (member riece-real-nickname users)
+	 users
+       (cons riece-real-nickname users)))))
+
 (provide 'riece-misc)
 
 ;;; riece-misc.el ends here
