@@ -31,7 +31,6 @@
   (require 'riece-emacs))
 
 (require 'riece-filter)
-(require 'riece-highlight)
 (require 'riece-display)
 (require 'riece-server)
 (require 'riece-compat)
@@ -119,12 +118,14 @@ If optional argument SAFE is nil, overwrite previous definitions."
     (setq keymap (symbol-value (car keymap)))))
   (let (key)
     (while plist
-      (when (symbolp (setq key (pop plist)))
-	(setq key (symbol-value key)))
+      (if (symbolp (setq key (car plist)))
+	  (setq key (symbol-value key)))
+      (setq plist (cdr plist))
       (if (or (not safe)
 	      (eq (lookup-key keymap key) 'undefined))
-	  (define-key keymap key (pop plist))
-	(pop plist)))))
+	  (define-key keymap key (car plist))
+	(car plist))
+      (setq plist (cdr plist)))))
 
 (when t
   (riece-define-keys riece-dialogue-mode-map
@@ -144,6 +145,7 @@ If optional argument SAFE is nil, overwrite previous definitions."
     "\C-to" riece-command-toggle-own-freeze
     "\C-tu" riece-command-toggle-user-list-buffer-mode
     "\C-tc" riece-command-toggle-channel-buffer-mode
+    "\C-tC" riece-command-toggle-channel-list-buffer-mode
     "i" riece-command-invite
     "j" riece-command-join
     "\C-k" riece-command-kick
@@ -245,9 +247,9 @@ If optional argument SAFE is nil, overwrite previous definitions."
 If optional argument CONFIRM is non-nil, ask which IRC server to connect.
 If already connected, just pop up the windows."
   (interactive "P")
-  (riece-read-variables-files
-   (car command-line-args-left))
-  (pop command-line-args-left)
+  (riece-read-variables-files (if noninteractive
+				  (car command-line-args-left)))
+  (riece-insinuate-addons riece-addons)
   (run-hooks 'riece-after-load-startup-hook)
   (if (riece-server-opened)
       (riece-configure-windows)
@@ -413,6 +415,72 @@ Instead, these commands are available:
 	  (funcall (cdr (car alist))))
 	(setq alist (cdr alist))))))
 
+(defun riece-load-and-build-addon-dependencies (addons)
+  (let ((load-path (cons riece-addon-directory load-path))
+	dependencies
+	pointer)
+    (while addons
+      (require (car addons))		;error will be reported here
+      (let* ((requires
+	      (funcall (or (intern-soft
+			    (concat (symbol-name (car addons)) "-requires"))
+			   #'ignore)))
+	     (pointer requires)
+	     entry)
+	;; Increment succs' pred count.
+	(if (setq entry (assq (car addons) dependencies))
+	    (setcar (cdr entry) (+ (length requires) (nth 1 entry)))
+	  (setq dependencies (cons (list (car addons) (length requires))
+				   dependencies)))
+	;; Merge pred's succs.
+	(while pointer
+	  (if (setq entry (assq (car pointer) dependencies))
+	      (setcdr (cdr entry)
+		      (cons (car addons) (nthcdr 2 entry)))
+	    (setq dependencies (cons (list (car pointer) 0 (car addons))
+				     dependencies)))
+	  (setq pointer (cdr pointer))))
+      (setq addons (cdr addons)))
+    dependencies))
+
+(defun riece-insinuate-addons (addons)
+  (let ((pointer addons)
+	dependencies queue)
+    ;; Uniquify, first.
+    (while pointer
+      (if (memq (car pointer) (cdr pointer))
+	  (setcar pointer nil))
+      (setq pointer (cdr pointer)))
+    (setq dependencies (riece-load-and-build-addon-dependencies
+			(delq nil addons))
+	  pointer dependencies)
+    ;; Sort them.
+    (while pointer
+      (if (zerop (nth 1 (car pointer)))
+	  (setq dependencies (delq (car pointer) dependencies)
+		queue (cons (car pointer) queue)))
+      (setq pointer (cdr pointer)))
+    (setq addons nil)
+    (while queue
+      (setq addons (cons (car (car queue)) addons)
+	    pointer (nthcdr 2 (car queue)))
+      (while pointer
+	(let* ((entry (assq (car pointer) dependencies))
+	       (count (1- (nth 1 entry))))
+	  (if (zerop count)
+	      (progn
+		(setq dependencies (delq entry dependencies)
+		      queue (nconc queue (list entry))))
+	    (setcar (cdr entry) count)))
+	(setq pointer (cdr pointer)))
+      (setq queue (cdr queue)))
+    (if dependencies
+	(error "Circular add-on dependency found"))
+    (while addons
+      (require (car addons))		;implicit dependency
+      (funcall (intern (concat (symbol-name (car addons)) "-insinuate")))
+      (setq addons (cdr addons)))))
+
 (provide 'riece)
 
 ;;; riece.el ends here
